#!/bin/sh

. "${_EXEC}"/pdiread.sh

edit_card(){
  local coursefile="$_DATA/courses/$1" 
  local tempfile course

  . $_EXEC/session_lock.sh

  if ! tempfile="$(CHECK_SLOCK "$coursefile")"; then
    printf '[div .message %s]' "$(l10n "This course is not set up for editing within this session.")"
  else
    course="$(pdi_load "$tempfile")"
    cat <<-EOF
	[form .course #${coursefile##*/} action="/cards/update_course.sh" method="POST"
	  [input type="hidden" name="tid" value="$(transid ${tempfile})"]
	]
	EOF
  fi
}

print_course(){
  local coursefile="$1"
  local course="$(pdi_load "$coursefile")"
  cat <<-EOF
    [div .course #${coursefile##*/}
      [div .section .basic &shy;$(
        cal_item "$course" SUMMARY DTSTART RRULE
      )]
      [div .section .COMMENT   &shy;$(cal_item "$course" COMMENT)]
      [div .section .attendance [h3 $(l10n course_attendance) ] [ul &shy;
        $(grep -F "	${cardfile##*/}" "$_DATA/mappings/attendance" |while read each discard; do
          printf '[li [a .item .attendance href="/courses#%s" &shy;%s]]' \
                 "$each" \
                 "$(pdi_value "$(pdi_load "$_DATA/ical/$each")" SUMMARY |unescape |HTML)"
        done)]
      ]
      [div .control
        [a .item href="/courses/edit_course.sh?course=${coursefile##*/}" $(l10n edit)]
        [a .item href="/courses/export_pdf.sh?course=${coursefile##*/}" target="blank" $(l10n courselist)]
        [a .item href="/courses/export_ical.sh?course=${coursefile##*/}" $(l10n ics_export)]
        [a .item href="mailto:zack@vuesch.org?bcc=$(course_mail "${coursefile##*/}")" $(l10n course_mail)]
      ]
    ]
	EOF
}

print_courses(){
  local calfile cachefile date size name ldate=0 lsize lname

  while read calfile; do
    cachefile="${_DATA}/cache/${calfile##*/}.cache"
    if [ -s "$cachefile" -a "$cachefile" -nt "$calfile" ]; then
      cat "$cachefile"
    else
      print_course "$calfile" |tee "$cachefile"
    fi
  done
}

order_courses() {
  local calfile course

  while read calfile; do
    icstime="$(pdi_value "$(pdi_load "$calfile")" DTSTART |cal_date)"
    case $order in
      DOW) printf '%s	%s\n' "$(date -d "$icstime" "+%u %H:%M:%S")" "$calfile";;
      TOD) printf '%s	%s\n' "$(date -d "$icstime" "+%H:%M:%S")" "$calfile";;
    esac
  done \
  | sort \
  | sed -E 's;^.*\t;;g'
}

list_courses(){
  printf '%s\n' ${_DATA}/courses/*.ics \
  | order_courses \
  | print_courses
}
